---
applyTo: '**/*.cff, **/*.json, **/*.yaml, **/*.yml, **/.clang-format'
---

# JSON and YAML

- By default, output should be recursively sorted by key.
- Use 2-space indentation.
- YAML: use single quotes for strings where possible.
- Run `yarn prettier -w` to format JSON and YAML files.
